@@ -76,8 +76,8 @@
 #define __NR_setrlimit               75
 #define __NR_getrlimit               76
 #define __NR_getrusage               77
-#define __NR_gettimeofday            78
-#define __NR_settimeofday            79
+#define __NR_gettimeofday_time32            78
+#define __NR_settimeofday_time32            79
 #define __NR_getgroups               80
 #define __NR_setgroups               81
 #define __NR_select                  82
@@ -238,14 +238,14 @@
 #define __NR_epoll_wait             238
 #define __NR_remap_file_pages       239
 #define __NR_timer_create           240
-#define __NR_timer_settime          241
-#define __NR_timer_gettime          242
+#define __NR_timer_settime32          241
+#define __NR_timer_gettime32          242
 #define __NR_timer_getoverrun       243
 #define __NR_timer_delete           244
-#define __NR_clock_settime          245
-#define __NR_clock_gettime          246
-#define __NR_clock_getres           247
-#define __NR_clock_nanosleep        248
+#define __NR_clock_settime32          245
+#define __NR_clock_gettime32          246
+#define __NR_clock_getres_time32           247
+#define __NR_clock_nanosleep_time32        248
 #define __NR_swapcontext            249
 #define __NR_tgkill                 250
 #define __NR_utimes                 251
@@ -307,8 +307,8 @@
 #define __NR_sync_file_range2	308
 #define __NR_fallocate		309
 #define __NR_subpage_prot		310
-#define __NR_timerfd_settime	311
-#define __NR_timerfd_gettime	312
+#define __NR_timerfd_settime32	311
+#define __NR_timerfd_gettime32	312
 #define __NR_signalfd4		313
 #define __NR_eventfd2		314
 #define __NR_epoll_create1	315
@@ -373,6 +373,52 @@
 #define __NR_pkey_mprotect         386
 #define __NR_rseq                  387
 #define __NR_io_pgetevents         388
+#define __NR_semget                393
+#define __NR_semctl                394
+#define __NR_shmget                395
+#define __NR_shmctl                396
+#define __NR_shmat                 397
+#define __NR_shmdt                 398
+#define __NR_msgget                399
+#define __NR_msgsnd                400
+#define __NR_msgrcv                401
+#define __NR_msgctl                402
+#define __NR_clock_gettime64       403
+#define __NR_clock_settime64       404
+#define __NR_clock_adjtime64       405
+#define __NR_clock_getres_time64   406
+#define __NR_clock_nanosleep_time64 407
+#define __NR_timer_gettime64       408
+#define __NR_timer_settime64       409
+#define __NR_timerfd_gettime64     410
+#define __NR_timerfd_settime64     411
+#define __NR_utimensat_time64      412
+#define __NR_pselect6_time64       413
+#define __NR_ppoll_time64          414
+#define __NR_io_pgetevents_time64  416
+#define __NR_recvmmsg_time64       417
+#define __NR_mq_timedsend_time64   418
+#define __NR_mq_timedreceive_time64 419
+#define __NR_semtimedop_time64     420
+#define __NR_rt_sigtimedwait_time64 421
+#define __NR_futex_time64          422
+#define __NR_sched_rr_get_interval_time64 423
+#define __NR_pidfd_send_signal     424
+#define __NR_io_uring_setup        425
+#define __NR_io_uring_enter        426
+#define __NR_io_uring_register     427
+#define __NR_open_tree		428
+#define __NR_move_mount		429
+#define __NR_fsopen		430
+#define __NR_fsconfig		431
+#define __NR_fsmount		432
+#define __NR_fspick		433
+#define __NR_pidfd_open		434
+#define __NR_clone3		435
+#define __NR_close_range	436
+#define __NR_openat2		437
+#define __NR_pidfd_getfd	438
+#define __NR_faccessat2		439
 
 #define SYS_restart_syscall          0
 #define SYS_exit                     1
@@ -452,8 +498,8 @@
 #define SYS_setrlimit               75
 #define SYS_getrlimit               76
 #define SYS_getrusage               77
-#define SYS_gettimeofday            78
-#define SYS_settimeofday            79
+#define SYS_gettimeofday_time32            78
+#define SYS_settimeofday_time32            79
 #define SYS_getgroups               80
 #define SYS_setgroups               81
 #define SYS_select                  82
@@ -614,14 +660,14 @@
 #define SYS_epoll_wait             238
 #define SYS_remap_file_pages       239
 #define SYS_timer_create           240
-#define SYS_timer_settime          241
-#define SYS_timer_gettime          242
+#define SYS_timer_settime32          241
+#define SYS_timer_gettime32          242
 #define SYS_timer_getoverrun       243
 #define SYS_timer_delete           244
-#define SYS_clock_settime          245
-#define SYS_clock_gettime          246
-#define SYS_clock_getres           247
-#define SYS_clock_nanosleep        248
+#define SYS_clock_settime32          245
+#define SYS_clock_gettime32          246
+#define SYS_clock_getres_time32           247
+#define SYS_clock_nanosleep_time32        248
 #define SYS_swapcontext            249
 #define SYS_tgkill                 250
 #define SYS_utimes                 251
@@ -683,8 +729,8 @@
 #define SYS_sync_file_range2	308
 #define SYS_fallocate		309
 #define SYS_subpage_prot		310
-#define SYS_timerfd_settime	311
-#define SYS_timerfd_gettime	312
+#define SYS_timerfd_settime32	311
+#define SYS_timerfd_gettime32	312
 #define SYS_signalfd4		313
 #define SYS_eventfd2		314
 #define SYS_epoll_create1	315
@@ -748,4 +794,50 @@
 #define SYS_pkey_free             385
 #define SYS_pkey_mprotect         386
 #define SYS_rseq                  387
-#define SYS_io_pgetevents         388
\ No newline at end of file
+#define SYS_io_pgetevents         388
+#define SYS_semget                393
+#define SYS_semctl                394
+#define SYS_shmget                395
+#define SYS_shmctl                396
+#define SYS_shmat                 397
+#define SYS_shmdt                 398
+#define SYS_msgget                399
+#define SYS_msgsnd                400
+#define SYS_msgrcv                401
+#define SYS_msgctl                402
+#define SYS_clock_gettime64       403
+#define SYS_clock_settime64       404
+#define SYS_clock_adjtime64       405
+#define SYS_clock_getres_time64   406
+#define SYS_clock_nanosleep_time64 407
+#define SYS_timer_gettime64       408
+#define SYS_timer_settime64       409
+#define SYS_timerfd_gettime64     410
+#define SYS_timerfd_settime64     411
+#define SYS_utimensat_time64      412
+#define SYS_pselect6_time64       413
+#define SYS_ppoll_time64          414
+#define SYS_io_pgetevents_time64  416
+#define SYS_recvmmsg_time64       417
+#define SYS_mq_timedsend_time64   418
+#define SYS_mq_timedreceive_time64 419
+#define SYS_semtimedop_time64     420
+#define SYS_rt_sigtimedwait_time64 421
+#define SYS_futex_time64          422
+#define SYS_sched_rr_get_interval_time64 423
+#define SYS_pidfd_send_signal     424
+#define SYS_io_uring_setup        425
+#define SYS_io_uring_enter        426
+#define SYS_io_uring_register     427
+#define SYS_open_tree		428
+#define SYS_move_mount		429
+#define SYS_fsopen		430
+#define SYS_fsconfig		431
+#define SYS_fsmount		432
+#define SYS_fspick		433
+#define SYS_pidfd_open		434
+#define SYS_clone3		435
+#define SYS_close_range	436
+#define SYS_openat2		437
+#define SYS_pidfd_getfd	438
+#define SYS_faccessat2		439
\ No newline at end of file
